Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NOPHandshakeFunc ¶
Types ¶
type DefaultDecoder ¶
type DefaultDecoder struct{}
type GOBDecoder ¶
type GOBDecoder struct {
}
type Message ¶
Message holds any arbitrary data that is being sent over the each transport between two nodes in the network.
type TCPPeer ¶
type TCPPeer struct {
// contains filtered or unexported fields
}
TCPPeer represent the remote node over a TCP established connection.
type TCPTransport ¶
type TCPTransport struct {
TCPTransportOpts
// contains filtered or unexported fields
}
func NewTCPTransport ¶
func NewTCPTransport(opts TCPTransportOpts) *TCPTransport
func (*TCPTransport) ListenAndAccept ¶
func (t *TCPTransport) ListenAndAccept() error
type TCPTransportOpts ¶
type TCPTransportOpts struct {
ListenAddr string
HandshakeFunc HandshakeFunc
Decoder Decoder
}
Click to show internal directories.
Click to hide internal directories.